================================
:code:`Trakt['users/*/lists/*']`
================================

.. automodule:: trakt.interfaces.users.lists.list_

  .. autoclass:: UsersListInterface
    :members: add, delete, get, items, like, remove, unlike, update
    :undoc-members:
